@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: css-text
 version: 0.1.2.1
-id: css-text-0.1.2.1-560c0698a8f53de36ee4bd610e239c26
-key: csste_LmgV1K0BOP72irXjucwwOa
+id: css-text-0.1.2.1-9e91a6e24ab9d04d01b694bbf376f115
+key: csste_4KSQSf83xgaFOGmAy34cfM
 license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -18,11 +18,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/css-text-0.1.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/css-text-0.1.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/css-text-0.1.2.1
-hs-libraries: HScss-text-0.1.2.1-LmgV1K0BOP72irXjucwwOa
+hs-libraries: HScss-text-0.1.2.1-4KSQSf83xgaFOGmAy34cfM
 depends:
-    attoparsec-0.13.0.1-57451b44323b331c08be1b712bdc3810
+    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
 haddock-interfaces: /usr/share/doc/haskell-css-text/html/css-text.haddock
 haddock-html: /usr/share/doc/haskell-css-text/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
